@@ -1,28 +1,5 @@
 var NAVTREEINDEX81 =
 {
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#a3cd543dae19eba9aa753c26665fc32bb":[3,0,0,0,0,48,97,8],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#a5a81389ae6f36d1fde653d70af98f188":[2,0,0,0,0,49,102,5],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#a5a81389ae6f36d1fde653d70af98f188":[3,0,0,0,0,48,97,5],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#a79969eb50f258a25f546d66cbb3a8a4a":[2,0,0,0,0,49,102,11],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#a79969eb50f258a25f546d66cbb3a8a4a":[3,0,0,0,0,48,97,11],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#aa6269c8a030abd20715f68dff5bb49da":[2,0,0,0,0,49,102,3],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#aa6269c8a030abd20715f68dff5bb49da":[3,0,0,0,0,48,97,3],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#abc5d3d618e710522a749e7697551a492":[2,0,0,0,0,49,102,10],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#abc5d3d618e710522a749e7697551a492":[3,0,0,0,0,48,97,10],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#af209206c4d79b248639aed2af76f5a8c":[2,0,0,0,0,49,102,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#af209206c4d79b248639aed2af76f5a8c":[3,0,0,0,0,48,97,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#af37b8f0296440debbcfe50437339185f":[2,0,0,0,0,49,102,6],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html#af37b8f0296440debbcfe50437339185f":[3,0,0,0,0,48,97,6],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html":[2,0,0,0,0,49,103],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html":[3,0,0,0,0,48,98],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a1bbe8f1b360c12007069e3e41ac86e4e":[2,0,0,0,0,49,103,8],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a1bbe8f1b360c12007069e3e41ac86e4e":[3,0,0,0,0,48,98,8],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a43b7649553c6599be2f86ec04726d9cb":[2,0,0,0,0,49,103,10],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a43b7649553c6599be2f86ec04726d9cb":[3,0,0,0,0,48,98,10],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a51fb969f7adaab0afcede1155cf484c7":[2,0,0,0,0,49,103,4],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a51fb969f7adaab0afcede1155cf484c7":[3,0,0,0,0,48,98,4],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a648f70c26079abaac487e2b59eaad57c":[2,0,0,0,0,49,103,1],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a648f70c26079abaac487e2b59eaad57c":[3,0,0,0,0,48,98,1],
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a8d6cee36618bf34c916772e45866b3f4":[2,0,0,0,0,49,103,6],
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a8d6cee36618bf34c916772e45866b3f4":[3,0,0,0,0,48,98,6],
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a920edf38e6677bfc591227085d1bc963":[2,0,0,0,0,49,103,5],
@@ -197,57 +174,80 @@ var NAVTREEINDEX81 =
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XViewAccess.html#a575a4ccb502083eb23011fc39d887037":[3,0,0,0,0,48,1,10,1],
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XViewAccess.html#a60e79aa9203ecbab9c914d810b58314a":[2,0,0,0,0,49,6,11,0],
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XViewAccess.html#a60e79aa9203ecbab9c914d810b58314a":[3,0,0,0,0,48,1,10,0],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html":[2,0,0,0,0,50,39],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html":[2,0,0,0,0,50,40],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html":[3,0,0,0,0,49,21],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#a3d9f386bc1d232e5a6a7c12d37558e9d":[2,0,0,0,0,50,39,3],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#a3d9f386bc1d232e5a6a7c12d37558e9d":[2,0,0,0,0,50,40,3],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#a3d9f386bc1d232e5a6a7c12d37558e9d":[3,0,0,0,0,49,21,3],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#aaa77bea01f2eb49214282d17e749c504":[2,0,0,0,0,50,39,2],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#aaa77bea01f2eb49214282d17e749c504":[2,0,0,0,0,50,40,2],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#aaa77bea01f2eb49214282d17e749c504":[3,0,0,0,0,49,21,2],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#ab3a0b3e9ea8b6c2611bec72298d2bcef":[2,0,0,0,0,50,39,0],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#ab3a0b3e9ea8b6c2611bec72298d2bcef":[2,0,0,0,0,50,40,0],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#ab3a0b3e9ea8b6c2611bec72298d2bcef":[3,0,0,0,0,49,21,0],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#ac20bf77a25bf9a9de0b0f7d1361ecd9b":[2,0,0,0,0,50,39,1],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#ac20bf77a25bf9a9de0b0f7d1361ecd9b":[2,0,0,0,0,50,40,1],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#ac20bf77a25bf9a9de0b0f7d1361ecd9b":[3,0,0,0,0,49,21,1],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#ac3d2f855f9fa9d5a59857780c2cb1c66":[2,0,0,0,0,50,39,5],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#ac3d2f855f9fa9d5a59857780c2cb1c66":[2,0,0,0,0,50,40,5],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#ac3d2f855f9fa9d5a59857780c2cb1c66":[3,0,0,0,0,49,21,5],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#af1c92ed856342000f98a3a8f5fef6d39":[2,0,0,0,0,50,39,4],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#af1c92ed856342000f98a3a8f5fef6d39":[2,0,0,0,0,50,40,4],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XArray.html#af1c92ed856342000f98a3a8f5fef6d39":[3,0,0,0,0,49,21,4],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html":[2,0,0,0,0,50,40],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html":[2,0,0,0,0,50,41],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html":[3,0,0,0,0,49,22],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#a491abdccc22ccf984fa5f5022f6a9219":[2,0,0,0,0,50,40,2],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#a491abdccc22ccf984fa5f5022f6a9219":[2,0,0,0,0,50,41,2],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#a491abdccc22ccf984fa5f5022f6a9219":[3,0,0,0,0,49,22,2],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#a6ad6e03503d1c780380cf9115087578c":[2,0,0,0,0,50,40,0],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#a6ad6e03503d1c780380cf9115087578c":[2,0,0,0,0,50,41,0],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#a6ad6e03503d1c780380cf9115087578c":[3,0,0,0,0,49,22,0],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#ade86b652e32e64639a5754838f6c8e83":[2,0,0,0,0,50,40,1],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#ade86b652e32e64639a5754838f6c8e83":[2,0,0,0,0,50,41,1],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#ade86b652e32e64639a5754838f6c8e83":[3,0,0,0,0,49,22,1],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html":[2,0,0,0,0,50,41],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html":[2,0,0,0,0,50,42],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html":[3,0,0,0,0,49,23],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#a68a7dbb47600d57bf9c3dd956d6ed4f8":[2,0,0,0,0,50,41,0],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#a68a7dbb47600d57bf9c3dd956d6ed4f8":[2,0,0,0,0,50,42,0],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#a68a7dbb47600d57bf9c3dd956d6ed4f8":[3,0,0,0,0,49,23,0],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#a7e1b18c653e0709044cac8f56265d9a0":[2,0,0,0,0,50,41,1],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#a7e1b18c653e0709044cac8f56265d9a0":[2,0,0,0,0,50,42,1],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#a7e1b18c653e0709044cac8f56265d9a0":[3,0,0,0,0,49,23,1],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#a9d8d73ef070807713a9a05ee76a8aa12":[2,0,0,0,0,50,41,4],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#a9d8d73ef070807713a9a05ee76a8aa12":[2,0,0,0,0,50,42,4],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#a9d8d73ef070807713a9a05ee76a8aa12":[3,0,0,0,0,49,23,4],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#af10444d3baf84c8f716653a38a6537ab":[2,0,0,0,0,50,41,3],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#af10444d3baf84c8f716653a38a6537ab":[2,0,0,0,0,50,42,3],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#af10444d3baf84c8f716653a38a6537ab":[3,0,0,0,0,49,23,3],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#af740d19b342231e041af9db2a4d1a508":[2,0,0,0,0,50,41,2],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#af740d19b342231e041af9db2a4d1a508":[2,0,0,0,0,50,42,2],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html#af740d19b342231e041af9db2a4d1a508":[3,0,0,0,0,49,23,2],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html":[2,0,0,0,0,50,42],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html":[2,0,0,0,0,50,43],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html":[3,0,0,0,0,49,24],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a114c3f1c5ce7fb6fb70575c30727e5ef":[2,0,0,0,0,50,42,0],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a114c3f1c5ce7fb6fb70575c30727e5ef":[2,0,0,0,0,50,43,0],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a114c3f1c5ce7fb6fb70575c30727e5ef":[3,0,0,0,0,49,24,0],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a1bd7c732653e9cd2d8e01873eee5aec8":[2,0,0,0,0,50,42,3],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a1bd7c732653e9cd2d8e01873eee5aec8":[2,0,0,0,0,50,43,3],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a1bd7c732653e9cd2d8e01873eee5aec8":[3,0,0,0,0,49,24,3],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a1c6e76575abeb335c117c56769aae836":[2,0,0,0,0,50,42,4],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a1c6e76575abeb335c117c56769aae836":[2,0,0,0,0,50,43,4],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a1c6e76575abeb335c117c56769aae836":[3,0,0,0,0,49,24,4],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a1d9399427f4ed995d7733dbf5b101097":[2,0,0,0,0,50,42,1],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a1d9399427f4ed995d7733dbf5b101097":[2,0,0,0,0,50,43,1],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#a1d9399427f4ed995d7733dbf5b101097":[3,0,0,0,0,49,24,1],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#af740d19b342231e041af9db2a4d1a508":[2,0,0,0,0,50,42,2],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#af740d19b342231e041af9db2a4d1a508":[2,0,0,0,0,50,43,2],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XClob.html#af740d19b342231e041af9db2a4d1a508":[3,0,0,0,0,49,24,2],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XCloseable.html":[2,0,0,0,0,50,43],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XCloseable.html":[2,0,0,0,0,50,44],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XCloseable.html":[3,0,0,0,0,49,25],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XCloseable.html#a5ae591df94fc66ccb85cbb6565368bca":[2,0,0,0,0,50,43,0],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XCloseable.html#a5ae591df94fc66ccb85cbb6565368bca":[2,0,0,0,0,50,44,0],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XCloseable.html#a5ae591df94fc66ccb85cbb6565368bca":[3,0,0,0,0,49,25,0],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XColumnLocate.html":[2,0,0,0,0,50,44],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XColumnLocate.html":[2,0,0,0,0,50,45],
 "interfacecom_1_1sun_1_1star_1_1sdbc_1_1XColumnLocate.html":[3,0,0,0,0,49,26],
-"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XColumnLocate.html#a7b04b938c2a6cf3148545fa4f94c3ee7":[2,0,0,0,0,50,44,0]
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XColumnLocate.html#a7b04b938c2a6cf3148545fa4f94c3ee7":[2,0,0,0,0,50,45,0],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XColumnLocate.html#a7b04b938c2a6cf3148545fa4f94c3ee7":[3,0,0,0,0,49,26,0],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html":[2,0,0,0,0,50,46],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html":[3,0,0,0,0,49,27],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a071de472f6ac976c658e4643f3fb3d0c":[2,0,0,0,0,50,46,12],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a071de472f6ac976c658e4643f3fb3d0c":[3,0,0,0,0,49,27,12],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a1729b528c79d48f8cb0576f97f27c8ec":[2,0,0,0,0,50,46,5],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a1729b528c79d48f8cb0576f97f27c8ec":[3,0,0,0,0,49,27,5],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a24e36eb8502ea7dd6578ae50a54a91c4":[2,0,0,0,0,50,46,16],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a24e36eb8502ea7dd6578ae50a54a91c4":[3,0,0,0,0,49,27,16],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a2a47cc6d3e8ee50472aa25241a592d63":[2,0,0,0,0,50,46,1],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a2a47cc6d3e8ee50472aa25241a592d63":[3,0,0,0,0,49,27,1],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a34ee27965f33b80d5101539f4bf265f1":[2,0,0,0,0,50,46,3],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a34ee27965f33b80d5101539f4bf265f1":[3,0,0,0,0,49,27,3],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a382c9b8dfeea5bfbe70869bca6d4a9a6":[2,0,0,0,0,50,46,14],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a382c9b8dfeea5bfbe70869bca6d4a9a6":[3,0,0,0,0,49,27,14],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a41879a91d8ac21b4138f8a65fba3678b":[2,0,0,0,0,50,46,11],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a41879a91d8ac21b4138f8a65fba3678b":[3,0,0,0,0,49,27,11],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a421efd5158da428e59e8e80dafee4536":[2,0,0,0,0,50,46,2],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a421efd5158da428e59e8e80dafee4536":[3,0,0,0,0,49,27,2],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a4bc7c90e1f4048197bac2c5ff797e9be":[2,0,0,0,0,50,46,7],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a4bc7c90e1f4048197bac2c5ff797e9be":[3,0,0,0,0,49,27,7],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a522a1f927a145be2d75085d4d2019154":[2,0,0,0,0,50,46,15],
+"interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#a522a1f927a145be2d75085d4d2019154":[3,0,0,0,0,49,27,15]
 };
